==> react-lds-8.7.0.tgz: package/es/components/Carousel/Carousel.js <==
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/es6.number.constructor";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEqual from 'lodash-es/isEqual';
import { IconButton } from '../Button';

var Carousel =
/*#__PURE__*/
function (_Component) {
  _inherits(Carousel, _Component);

  function Carousel() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Carousel);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Carousel)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "state", {
      activeIndex: 0,
      panels: []
    });

    _defineProperty(_assertThisInitialized(_this), "autoPlayId", null);

    _defineProperty(_assertThisInitialized(_this), "onClickIndicator", function (e) {
      e.stopPropagation();
      e.target.blur();

      _this.setActivePanel(Number(e.target.dataset.index));
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyboardInteraction", function (e) {
      if (e.keyCode === 37) {
        _this.activatePreviousPanel();
      } else if (e.keyCode === 39) {
        _this.activateNextPanel();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "toggleAutoPlay", function () {
      if (_this.autoPlayId) {
        _this.stopAutoPlay();
      } else {
        _this.startAutoPlay();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "activateNextPanel", function () {
      var _this$state = _this.state,
          activeIndex = _this$state.activeIndex,
          panels = _this$state.panels;
      var nextActiveIndex = activeIndex + 1;

      if (nextActiveIndex >= panels.length) {
        _this.setActivePanel(0);
      } else {
        _this.setActivePanel(nextActiveIndex);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "activatePreviousPanel", function () {
      var _this$state2 = _this.state,
          activeIndex = _this$state2.activeIndex,
          panels = _this$state2.panels;
      var nextActiveIndex = activeIndex - 1;

      if (nextActiveIndex < 0) {
        _this.setActivePanel(panels.length - 1);
      } else {
        _this.setActivePanel(nextActiveIndex);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderIndicator", function (_ref, index) {
      var _ref$props = _ref.props,
          active = _ref$props.active,
          id = _ref$props.id,
          title = _ref$props.title;
      var tabIndex = active ? 0 : -1;
      var actionClasses = cx('slds-carousel__indicator-action', {
        'slds-is-active': active
      });
      return React.createElement("li", {
        className: "slds-carousel__indicator",
        key: id,
        role: "presentation"
      }, React.createElement("a", {
        className: actionClasses,
        role: "tab",
        tabIndex: tabIndex,
        "aria-selected": active,
        "aria-controls": id,
        onClick: _this.onClickIndicator,
        title: title,
        "data-index": index
      }, React.createElement("span", {
        className: "slds-assistive-text"
      }, title)));
    });

    return _this;
  }

  _createClass(Carousel, [{
    key: "componentWillMount",
    // eslint-disable-line react/sort-comp
    value: function componentWillMount() {
      var _this$props = this.props,
          autoPlayActive = _this$props.autoPlayActive,
          children = _this$props.children;
      this.updatePanels(children);

      if (autoPlayActive) {
        this.startAutoPlay();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref2) {
      var nextAutoPlayActive = _ref2.autoPlayActive,
          nextChildren = _ref2.children;
      var prevChildren = this.props.children;
      var prevAutoPlayActive = this.state.autoPlayActive;
      var childrenChanged = nextChildren.length !== prevChildren.length || !isEqual(nextChildren.map(function (_ref3) {
        var props = _ref3.props;
        return props;
      }), prevChildren.map(function (_ref4) {
        var props = _ref4.props;
        return props;
      }));

      if (childrenChanged) {
        this.updatePanels(nextChildren);
      }

      if (!!nextAutoPlayActive !== prevAutoPlayActive) {
        if (nextAutoPlayActive) this.startAutoPlay();else this.stopAutoPlay();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.autoPlayId) {
        clearInterval(this.autoPlayId);
      }
    }
  }, {
    key: "setActivePanel",
    value: function setActivePanel(nextActiveIndex) {
      var _this$state3 = this.state,
          activeIndex = _this$state3.activeIndex,
          panels = _this$state3.panels;

      var nextPanels = _toConsumableArray(panels);

      nextPanels[activeIndex] = React.cloneElement(nextPanels[activeIndex], {
        active: false
      });
      nextPanels[nextActiveIndex] = React.cloneElement(nextPanels[nextActiveIndex], {
        active: true
      });
      this.setState({
        activeIndex: nextActiveIndex,
        panels: nextPanels
      });
    }
  }, {
    key: "startAutoPlay",
    value: function startAutoPlay() {
      var autoPlayInterval = this.props.autoPlayInterval;
      this.autoPlayId = setInterval(this.activateNextPanel, autoPlayInterval);
      this.setState({
        autoPlayActive: true
      });
    }
  }, {
    key: "stopAutoPlay",
    value: function stopAutoPlay() {
      clearInterval(this.autoPlayId);
      this.autoPlayId = null;
      this.setState({
        autoPlayActive: false
      });
    }
  }, {
    key: "updatePanels",
    value: function updatePanels(panels) {
      var _this2 = this;

      var activeIndex = this.state.activeIndex;
      this.setState({
        activeIndex: Math.min(panels.length, activeIndex),
        panels: React.Children.map(panels, function (panel, index) {
          return React.cloneElement(panel, {
            active: activeIndex === index,
            onKeyboardInteraction: _this2.onKeyboardInteraction
          });
        })
      });
    }
  }, {
    key: "renderAutoPlay",
    value: function renderAutoPlay() {
      var _this$props2 = this.props,
          autoPlayStartText = _this$props2.autoPlayStartText,
          autoPlayStopText = _this$props2.autoPlayStopText;
      var autoPlayActive = this.state.autoPlayActive;
      var icon = autoPlayActive ? 'pause' : 'right';
      var assistiveText = autoPlayActive ? autoPlayStopText : autoPlayStartText;
      return React.createElement("span", {
        className: "slds-carousel__autoplay"
      }, React.createElement(IconButton, {
        icon: icon,
        border: "filled",
        sprite: "utility",
        onClick: this.toggleAutoPlay,
        size: "x-small",
        title: assistiveText
      }));
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          autoPlay = _this$props3.autoPlay,
          className = _this$props3.className;
      var _this$state4 = this.state,
          activeIndex = _this$state4.activeIndex,
          panels = _this$state4.panels;
      var sldsClasses = ['slds-carousel', className];
      var translateX = "translateX(-".concat(activeIndex * 100, "%)");
      return React.createElement("div", {
        className: cx(sldsClasses)
      }, React.createElement("div", {
        className: "slds-carousel__stage"
      }, autoPlay && this.renderAutoPlay(), React.createElement("div", {
        className: "slds-carousel__panels",
        style: {
          transform: translateX
        }
      }, panels), React.createElement("ul", {
        className: "slds-carousel__indicators",
        role: "tablist"
      }, panels.map(this.renderIndicator))));
    }
  }]);

  return Carousel;
}(Component);

Carousel.defaultProps = {
  autoPlay: false,
  autoPlayActive: false,
  autoPlayInterval: 4000,
  autoPlayStartText: 'Start auto-play',
  autoPlayStopText: 'Stop auto-play',
  children: [],
  className: null
};
Carousel.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * toggle autoplay mode
   */
  autoPlay: PropTypes.bool,

  /**
   * control whether autoplay is active or not
   */
  autoPlayActive: PropTypes.bool,

  /**
   * assistive text for autoplay button
   */
  autoPlayStartText: PropTypes.string,

  /**
   * assistive text for autoplay button
   */
  autoPlayStopText: PropTypes.string,

  /**
   * change autoplay interval, defaults to 4000ms
   */
  autoPlayInterval: PropTypes.number,

  /**
   * list of carousel panels
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string
} : {};
export default Carousel;

==> react-lds-9.1.0.tgz: package/es/components/Carousel/Carousel.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.number.constructor";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEqual from 'lodash-es/isEqual';
import { IconButton } from '../Button';

var Carousel =
/*#__PURE__*/
function (_Component) {
  _inherits(Carousel, _Component);

  function Carousel() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Carousel);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Carousel)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "state", {
      activeIndex: 0,
      panels: []
    });

    _defineProperty(_assertThisInitialized(_this), "autoPlayId", null);

    _defineProperty(_assertThisInitialized(_this), "onClickIndicator", function (e) {
      e.stopPropagation();
      e.target.blur();

      _this.setActivePanel(Number(e.target.dataset.index));
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyboardInteraction", function (e) {
      if (e.keyCode === 37) {
        _this.activatePreviousPanel();
      } else if (e.keyCode === 39) {
        _this.activateNextPanel();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "toggleAutoPlay", function () {
      if (_this.autoPlayId) {
        _this.stopAutoPlay();
      } else {
        _this.startAutoPlay();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "activateNextPanel", function () {
      var _this$state = _this.state,
          activeIndex = _this$state.activeIndex,
          panels = _this$state.panels;
      var nextActiveIndex = activeIndex + 1;

      if (nextActiveIndex >= panels.length) {
        _this.setActivePanel(0);
      } else {
        _this.setActivePanel(nextActiveIndex);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "activatePreviousPanel", function () {
      var _this$state2 = _this.state,
          activeIndex = _this$state2.activeIndex,
          panels = _this$state2.panels;
      var nextActiveIndex = activeIndex - 1;

      if (nextActiveIndex < 0) {
        _this.setActivePanel(panels.length - 1);
      } else {
        _this.setActivePanel(nextActiveIndex);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderIndicator", function (_ref, index) {
      var _ref$props = _ref.props,
          active = _ref$props.active,
          id = _ref$props.id,
          title = _ref$props.title;
      var tabIndex = active ? 0 : -1;
      var actionClasses = cx('slds-carousel__indicator-action', {
        'slds-is-active': active
      });
      return React.createElement("li", {
        className: "slds-carousel__indicator",
        key: id,
        role: "presentation"
      }, React.createElement("a", {
        className: actionClasses,
        role: "tab",
        tabIndex: tabIndex,
        "aria-selected": active,
        "aria-controls": id,
        onClick: _this.onClickIndicator,
        title: title,
        "data-index": index
      }, React.createElement("span", {
        className: "slds-assistive-text"
      }, title)));
    });

    return _this;
  }

  _createClass(Carousel, [{
    key: "componentWillMount",
    // eslint-disable-line react/sort-comp
    value: function componentWillMount() {
      var _this$props = this.props,
          autoPlayActive = _this$props.autoPlayActive,
          children = _this$props.children;
      this.updatePanels(children);

      if (autoPlayActive) {
        this.startAutoPlay();
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref2) {
      var nextAutoPlayActive = _ref2.autoPlayActive,
          nextChildren = _ref2.children;
      var prevChildren = this.props.children;
      var prevAutoPlayActive = this.state.autoPlayActive;
      var childrenChanged = nextChildren.length !== prevChildren.length || !isEqual(nextChildren.map(function (_ref3) {
        var props = _ref3.props;
        return props;
      }), prevChildren.map(function (_ref4) {
        var props = _ref4.props;
        return props;
      }));

      if (childrenChanged) {
        this.updatePanels(nextChildren);
      }

      if (!!nextAutoPlayActive !== prevAutoPlayActive) {
        if (nextAutoPlayActive) this.startAutoPlay();else this.stopAutoPlay();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      if (this.autoPlayId) {
        clearInterval(this.autoPlayId);
      }
    }
  }, {
    key: "setActivePanel",
    value: function setActivePanel(nextActiveIndex) {
      var _this$state3 = this.state,
          activeIndex = _this$state3.activeIndex,
          panels = _this$state3.panels;

      var nextPanels = _toConsumableArray(panels);

      nextPanels[activeIndex] = React.cloneElement(nextPanels[activeIndex], {
        active: false
      });
      nextPanels[nextActiveIndex] = React.cloneElement(nextPanels[nextActiveIndex], {
        active: true
      });
      this.setState({
        activeIndex: nextActiveIndex,
        panels: nextPanels
      });
    }
  }, {
    key: "startAutoPlay",
    value: function startAutoPlay() {
      var autoPlayInterval = this.props.autoPlayInterval;
      this.autoPlayId = setInterval(this.activateNextPanel, autoPlayInterval);
      this.setState({
        autoPlayActive: true
      });
    }
  }, {
    key: "stopAutoPlay",
    value: function stopAutoPlay() {
      clearInterval(this.autoPlayId);
      this.autoPlayId = null;
      this.setState({
        autoPlayActive: false
      });
    }
  }, {
    key: "updatePanels",
    value: function updatePanels(panels) {
      var _this2 = this;

      var activeIndex = this.state.activeIndex;
      this.setState({
        activeIndex: Math.min(panels.length, activeIndex),
        panels: React.Children.map(panels, function (panel, index) {
          return React.cloneElement(panel, {
            active: activeIndex === index,
            onKeyboardInteraction: _this2.onKeyboardInteraction
          });
        })
      });
    }
  }, {
    key: "renderAutoPlay",
    value: function renderAutoPlay() {
      var _this$props2 = this.props,
          autoPlayStartText = _this$props2.autoPlayStartText,
          autoPlayStopText = _this$props2.autoPlayStopText;
      var autoPlayActive = this.state.autoPlayActive;
      var icon = autoPlayActive ? 'pause' : 'right';
      var assistiveText = autoPlayActive ? autoPlayStopText : autoPlayStartText;
      return React.createElement("span", {
        className: "slds-carousel__autoplay"
      }, React.createElement(IconButton, {
        icon: icon,
        border: "filled",
        sprite: "utility",
        onClick: this.toggleAutoPlay,
        size: "x-small",
        title: assistiveText
      }));
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          autoPlay = _this$props3.autoPlay,
          className = _this$props3.className;
      var _this$state4 = this.state,
          activeIndex = _this$state4.activeIndex,
          panels = _this$state4.panels;
      var sldsClasses = ['slds-carousel', className];
      var translateX = "translateX(-".concat(activeIndex * 100, "%)");
      return React.createElement("div", {
        className: cx(sldsClasses)
      }, React.createElement("div", {
        className: "slds-carousel__stage"
      }, autoPlay && this.renderAutoPlay(), React.createElement("div", {
        className: "slds-carousel__panels",
        style: {
          transform: translateX
        }
      }, panels), React.createElement("ul", {
        className: "slds-carousel__indicators",
        role: "tablist"
      }, panels.map(this.renderIndicator))));
    }
  }]);

  return Carousel;
}(Component);

Carousel.defaultProps = {
  autoPlay: false,
  autoPlayActive: false,
  autoPlayInterval: 4000,
  autoPlayStartText: 'Start auto-play',
  autoPlayStopText: 'Stop auto-play',
  children: [],
  className: null
};
Carousel.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * toggle autoplay mode
   */
  autoPlay: PropTypes.bool,

  /**
   * control whether autoplay is active or not
   */
  autoPlayActive: PropTypes.bool,

  /**
   * assistive text for autoplay button
   */
  autoPlayStartText: PropTypes.string,

  /**
   * assistive text for autoplay button
   */
  autoPlayStopText: PropTypes.string,

  /**
   * change autoplay interval, defaults to 4000ms
   */
  autoPlayInterval: PropTypes.number,

  /**
   * list of carousel panels
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string
} : {};
export default Carousel;
